--- check_mysql.c.orig 2008-01-30 10:53:47.000000000 +0000
+++ check_mysql.c   2008-03-19 10:02:34.000000000 +0000
@@ -62,6 +62,7 @@
 int validate_arguments (void);
 void print_help (void);
 void print_usage (void);
+char *get_perf_data(char *);

 int
 main (int argc, char **argv)
@@ -108,6 +109,9 @@
  /* get the server stats */
  result = strdup (mysql_stat (&mysql));

+        /* Turn result into perf data */
+        result = get_perf_data(result);
+
  /* error checking once more */
  if (mysql_error (&mysql)) {
   if (mysql_errno (&mysql) == CR_SERVER_GONE_ERROR)
@@ -338,6 +342,76 @@
 }


+char *get_perf_data(char *line)
+{
+        /* Get performance data.  Ben Clewett, Feb 2005 */
+        /* This is quick and dirty, but should work if the MySQL output does not change. */
+        /* Tested on MySQL 4.0.11 -> 4.1.9 */
+
+        enum parse_state { st_none, st_name, st_space, st_value };
+        int i_line = -1, i_nv;
+        char name[30] = "";
+        char value[30] = "";
+        enum parse_state state = st_none;
+        static char s_out[1024];
+
+        sprintf(s_out, "%s |", line);
+
+        while (line[++i_line]) {
+
+                switch (state) {
+                case st_none:
+                        if (line[i_line] > ' ') {
+                                name[0] = '\'';
+                                name[1] = line[i_line];
+                                name[2] = 0;
+                                i_nv = 2;
+                                state = st_name;
+                        }
+                        break;
+                case st_name:
+                        if (line[i_line] == ':') {
+                                name[i_nv++] = '\'';
+                                name[i_nv] = 0;
+                                state = st_space;
+                        } else {
+                                name[i_nv++] = line[i_line];
+                                name[i_nv] = 0;
+                        }
+                        break;
+                case st_space:
+                        if (line[i_line] > ' ') {
+                                value[0] = line[i_line];
+                                value[1] = 0;
+                                i_nv = 1;
+                                state = st_value;
+                        }
+                        break;
+                case st_value:
+                        if (line[i_line] <= ' ') {
+                                state = st_none;
+                                sprintf(s_out, "%s %s=%s", s_out, name, value);
+                        } else {
+                                value[i_nv++] = line[i_line];
+                                value[i_nv] = 0;
+                        }
+                        break;
+                }
+
+        }
+
+        if (state == st_value) {
+                state = st_none;
+                sprintf(s_out, "%s %s=%s", s_out, name, value);
+        }
+
+        return s_out;
+
+}
+
+
+
+
 int
 validate_arguments (void)
 {
